summaryrefslogtreecommitdiffstats
path: root/macosx
diff options
context:
space:
mode:
authordynaflash <[email protected]>2009-11-18 20:27:18 +0000
committerdynaflash <[email protected]>2009-11-18 20:27:18 +0000
commit4563726e20b6ab9191d738e6343926c9f542c190 (patch)
tree33529135fdf6ed7337c4d602288722e56290c72d /macosx
parent99748f4b7308a892bfdab1f14ffa4d9e4e436e19 (diff)
MacGui: change the min and max bitrate for faac six channel discrete encodes.
- Patch by Rodeo so its his fault. ;) - Addresses http://forum.handbrake.fr/viewtopic.php?f=4&t=13114 git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@2942 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'macosx')
-rw-r--r--macosx/Controller.m8
1 files changed, 4 insertions, 4 deletions
diff --git a/macosx/Controller.m b/macosx/Controller.m
index 8fcd1ba7b..32b1395c2 100644
--- a/macosx/Controller.m
+++ b/macosx/Controller.m
@@ -5599,10 +5599,10 @@ the user is using "Custom" settings by determining the sender*/
/* check if we have a 6ch discrete conversion in either audio track */
if ([[mixdownPopUp selectedItem] tag] == HB_AMIXDOWN_6CH)
{
- /* FAAC is happy using our min bitrate of 32 kbps, even for 6ch */
- minbitrate = 32;
- /* If either mixdown popup includes 6-channel discrete, then allow up to 384 kbps */
- maxbitrate = 384;
+ /* FAAC has a minimum of 192 kbps for 6-channel discrete */
+ minbitrate = 192;
+ /* If either mixdown popup includes 6-channel discrete, then allow up to 448 kbps */
+ maxbitrate = 448;
break;
}
else